@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2018 Zabbix SIA
+** Copyright (C) 2001-2021 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -21,13 +21,13 @@ package com.zabbix.gateway;
 
 class GeneralInformation
 {
-	public static final String APPLICATION_NAME = "Zabbix Java Gateway";
-	public static final String REVISION_DATE = "30 July 2018";
-	public static final String REVISION = "83227";
-	public static final String VERSION = "2.2.23";
+	static final String APPLICATION_NAME = "Zabbix Java Gateway";
+	static final String REVISION_DATE = "25 January 2021";
+	static final String REVISION = "d3c78f993a";
+	static final String VERSION = "5.0.8";
 
-	public static void printVersion()
+	static void printVersion()
 	{
-		System.out.printf("%s v%s (revision %s) (%s)\n", APPLICATION_NAME, VERSION, REVISION, REVISION_DATE);
+		System.out.println(String.format("%s v%s (revision %s) (%s)", APPLICATION_NAME, VERSION, REVISION, REVISION_DATE));
 	}
 }
